from pydoc import locate


def get_all_fields(fields: list, rest: dict) -> list:
    for key in rest:
        fields.append(key)
    return fields


def str_to_class(path):
    try:
        my_class = locate(path)
    except ImportError:
        raise ValueError('Module does not exist')
    return my_class or None



class ElasticFilter:
    def __init__(self, scope, connector, request):
        self.connector = connector
        self.scope = scope
        self.rest = {}
        self.request = request

    def get_scope_other_fields(self):
        import urllib.parse as p
        query_string = p.parse_qs(self.request.META['QUERY_STRING'])

        fields = query_string[self.scope][0].split(',')
        rest = {}
        for item in query_string:
            if item in fields:
                rest[item] = query_string[item]
                fields.remove(item)

        return {"fields": fields,
                "rest": rest}



from setuptools import setup

with open("README.md", 'r') as f:
    long_description = f.read()

setup(name='django-elastic-filter',
      license="MIT",
      author='Saeed Hassani Borzadaran',
      author_email='hassanisaeed19@gmail.com',
      url="https://github.com/realsaeedhassani/django-elastic-filter",
      packages=['django-elastic-filter'])
